# eric7.Project.ProjectVenvConfigurationDialog

Module implementing a dialog to enter the configuration for the embedded environment of the project.

### Global Attributes

None

### Classes

ProjectVenvConfigurationDialog | Class implementing a dialog to enter the configuration for the embedded environment of the project.

### Functions

None

## ProjectVenvConfigurationDialog

Class implementing a dialog to enter the configuration for the embedded environment of the project.

### Derived from

QDialog, Ui_ProjectVenvConfigurationDialog

### Class Attributes

None

### Class Methods

None

### Methods

ProjectVenvConfigurationDialog | Constructor
__updateOK | Private method to update the enabled status of the OK button.
getData | Public method to get the entered data.
on_pythonExecPicker_editTextChanged | Private slot to handle changes of the entered Python interpreter path.

### Static Methods

None

#### ProjectVenvConfigurationDialog (Constructor)

ProjectVenvConfigurationDialog(venvName="", venvDirectory="", venvInterpreter="", execPath="", parent=None, )

Constructor

venvName (str)
  logical name of a virtual environment for editing
venvDirectory (str)
  directory of the virtual environment
venvInterpreter (str)
  Python interpreter of the virtual environment
execPath (str)
  search path string to be prepended to the PATH environment variable
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### ProjectVenvConfigurationDialog.__updateOK

__updateOK()

Private method to update the enabled status of the OK button.

#### ProjectVenvConfigurationDialog.getData

getData()

Public method to get the entered data.

Return:
  tuple containing the path of the selected Python interpreter and a string to be prepended to the PATH environment variable

Return Type:
  tuple of (str, str)

#### ProjectVenvConfigurationDialog.on_pythonExecPicker_editTextChanged

on_pythonExecPicker_editTextChanged(_txt)

Private slot to handle changes of the entered Python interpreter path.

_txt (str)
  entered Python interpreter path (unused)

Up